searchNodes=[{"doc":"Documentation for WiseGPTEx . This module provides functions to obtain the best completion from the OpenAI models (default: &quot;gpt-3.5-turbo&quot;) using the OpenAI API completions endpoint ( https://api.openai.com/v1/chat/completions ). The get_best_completion/2 and get_best_completion_with_resolver/2 functions take a question and an optional list of options to configure the API request. get_best_completion_with_resolver/2 also involves a secondary step to resolve the best completion among the options, which leads to an additional API call for a more accurate response. Installation Add wise_gpt_ex to your list of dependencies in mix.exs : def deps do [ { :wise_gpt_ex , &quot;~&gt; 0.3.0&quot; } ] end Add the OpenAI API key to your configuration file (e.g., config/config.exs): config :wise_gpt_ex , :openai_api_key , &quot;your_openai_api_key&quot; Examples Basic usage: iex&gt; WiseGPTEx . get_best_completion ( &quot;What is the capital of France?&quot; ) { :ok , &quot;Paris&quot; } iex&gt; WiseGPTEx . get_best_completion_with_resolver ( &quot;What is the capital of France?&quot; ) { :ok , &quot;Paris&quot; } Using all available options: iex&gt; opts = [ model : &quot;gpt-4&quot; , temperature : 0.7 , num_completions : 5 , timeout : 3_600_000 ] iex&gt; WiseGPTEx . get_best_completion ( &quot;What is the capital of France?&quot; , opts ) { :ok , &quot;Paris&quot; } iex&gt; WiseGPTEx . get_best_completion_with_resolver ( &quot;What is the capital of France?&quot; , opts ) { :ok , &quot;Paris&quot; } Note that the examples for the get_best_completion_with_resolver/2 function are similar to get_best_completion/2 . This is because the difference between these two functions is in the method of how they select the best completion, not in their usage or the nature of their inputs or outputs. The get_best_completion_with_resolver/2 function will perform an additional API call to get a more accurate completion, which can be beneficial for complex or ambiguous queries. Options The following options can be passed to the get_best_completion/2 and get_best_completion_with_resolver/2 functions: :model - The name of the model to use (default: &quot;gpt-3.5-turbo&quot;). All OpenAI models are supported. :temperature - Controls the randomness of the model's output. Higher values result in more diverse responses (default: 0.5). :num_completions - The number of completions to generate (default: 3). :timeout - The maximum time in milliseconds to wait for a response from the OpenAI API (default: 3_600_000 ms, or 60 minutes).","ref":"WiseGPTEx.html","title":"WiseGPTEx","type":"module"},{"doc":"get_best_completion/2 attempts to answer a given question using OpenAI's completion endpoint. Params: question : a binary string containing the question to be answered opts : a keyword list of options to configure the API request Returns: {:ok, binary()} : the best completion for the given question {:error, any()} : an error message in the case of failure Example: iex&gt; WiseGPTEx . get_best_completion ( &quot;What is the capital of France?&quot; ) { :ok , &quot;Paris&quot; } Options: The function accepts the following options: :model - The name of the model to use (default: &quot;gpt-3.5-turbo&quot;). All OpenAI models are supported. :temperature - Controls the randomness of the model's output. Higher values result in more diverse responses (default: 0.5). :num_completions - The number of completions to generate (default: 3). :timeout - The maximum time in milliseconds to wait for a response from the OpenAI API (default: 3_600_000 ms, or 60 minutes).","ref":"WiseGPTEx.html#get_best_completion/2","title":"WiseGPTEx.get_best_completion/2","type":"function"},{"doc":"get_best_completion_with_resolver/2 is similar to get_best_completion/2 but uses a secondary step to resolve the best completion among the options. This function will perform an additional API call to get a more accurate completion, which can be beneficial for complex or ambiguous queries. Params: question : a binary string containing the question to be answered opts : a keyword list of options to configure the API request Returns: {:ok, binary()}: the best completion for the given question - : an error message in the case of failure Example: iex&gt; WiseGPTEx . get_best_completion_with_resolver ( &quot;What is the capital of France?&quot; ) { :ok , &quot;Paris&quot; } Options: The function accepts the following options: :model - The name of the model to use (default: &quot;gpt-3.5-turbo&quot;). All OpenAI models are supported. :temperature - Controls the randomness of the model's output. Higher values result in more diverse responses (default: 0.5). - :num_completions - The number of completions to generate (default: 3). - :timeout` - The maximum time in milliseconds to wait for a response from the OpenAI API (default: 3_600_000 ms, or 60 minutes).","ref":"WiseGPTEx.html#get_best_completion_with_resolver/2","title":"WiseGPTEx.get_best_completion_with_resolver/2","type":"function"},{"doc":"Documentation for WiseGPTEx.OpenAIHTTPClient . This module contains functions to interact with the OpenAI API to get completions with reasoning and determine the best completion. It is used internally by the WiseGPTEx module and is not intended to be called directly by users. The main functions in this module are: get_completions_with_reasoning/2 - Retrieves completions with reasoning from the OpenAI API based on a given message and an optional list of options. get_best_completion/3 - Determines the best completion from a list of completions and an optional list of options.","ref":"WiseGPTEx.OpenAIHTTPClient.html","title":"WiseGPTEx.OpenAIHTTPClient","type":"module"},{"doc":"","ref":"WiseGPTEx.OpenAIHTTPClient.html#get_best_completion/3","title":"WiseGPTEx.OpenAIHTTPClient.get_best_completion/3","type":"function"},{"doc":"","ref":"WiseGPTEx.OpenAIHTTPClient.html#get_completions_with_reasoning/2","title":"WiseGPTEx.OpenAIHTTPClient.get_completions_with_reasoning/2","type":"function"},{"doc":"","ref":"WiseGPTEx.OpenAIHTTPClient.html#get_resolver_completion/4","title":"WiseGPTEx.OpenAIHTTPClient.get_resolver_completion/4","type":"function"},{"doc":"Provides facilities for processing some of the responses from third party APIs.","ref":"WiseGPTEx.OpenAIUtils.html","title":"WiseGPTEx.OpenAIUtils","type":"module"},{"doc":"A function that takes a list of completions and returns the content of the first one that finished. Example iex&gt; body = %{ ...&gt; &quot;choices&quot; =&gt; [ ...&gt; %{ ...&gt; &quot;finish_reason&quot; =&gt; &quot;stop&quot; , ...&gt; &quot;index&quot; =&gt; 0 , ...&gt; &quot;message&quot; =&gt; %{ ...&gt; &quot;content&quot; =&gt; &quot;Correct Answer: Option 1.&quot; , ...&gt; &quot;role&quot; =&gt; &quot;assistant&quot; ...&gt; } ...&gt; } ...&gt; ] ...&gt; } ...&gt; WiseGPTEx.OpenAIUtils . extract_completion ( body ) &quot;Correct Answer: Option 1.&quot;","ref":"WiseGPTEx.OpenAIUtils.html#extract_completion/1","title":"WiseGPTEx.OpenAIUtils.extract_completion/1","type":"function"},{"doc":"A function that takes a list of completions and returns the content of all that finished. Example iex&gt; body = %{ ...&gt; &quot;choices&quot; =&gt; [ ...&gt; %{ ...&gt; &quot;finish_reason&quot; =&gt; &quot;stop&quot; , ...&gt; &quot;index&quot; =&gt; 0 , ...&gt; &quot;message&quot; =&gt; %{ ...&gt; &quot;content&quot; =&gt; &quot;First, 456 * 23421 = 54,456.&quot; , ...&gt; &quot;role&quot; =&gt; &quot;assistant&quot; ...&gt; } ...&gt; } , ...&gt; %{ ...&gt; &quot;finish_reason&quot; =&gt; &quot;stop&quot; , ...&gt; &quot;index&quot; =&gt; 1 , ...&gt; &quot;message&quot; =&gt; %{ ...&gt; &quot;content&quot; =&gt; &quot;Second, we get the answer: 10,686,876.&quot; , ...&gt; &quot;role&quot; =&gt; &quot;assistant&quot; ...&gt; } ...&gt; } ...&gt; ] ...&gt; } ...&gt; WiseGPTEx.OpenAIUtils . extract_completions ( body ) [ &quot;First, 456 * 23421 = 54,456.&quot; , &quot;Second, we get the answer: 10,686,876.&quot; ]","ref":"WiseGPTEx.OpenAIUtils.html#extract_completions/1","title":"WiseGPTEx.OpenAIUtils.extract_completions/1","type":"function"},{"doc":"A function that takes a list of completions and prepares them as answer options. Each option is prefixed with &quot;Answer Option&quot; followed by its index in the list, and all options are joined together with newline. Example iex&gt; completions = [ &quot;PHP&quot; , &quot;Elixir&quot; , &quot;Go&quot; ] ...&gt; WiseGPTEx.OpenAIUtils . prepare_completion_options ( completions ) &quot;Answer Option 1: PHP \\n Answer Option 2: Elixir \\n Answer Option 3: Go&quot;","ref":"WiseGPTEx.OpenAIUtils.html#prepare_completion_options/1","title":"WiseGPTEx.OpenAIUtils.prepare_completion_options/1","type":"function"},{"doc":"A function that takes a message and returns a prompt with a reasoning template. Example iex&gt; WiseGPTEx.OpenAIUtils . reasoning_prompt ( &quot;What is 2+2?&quot; ) &quot;Question: What is 2+2? \\n Answer: Let&#39;s work this out in a step by step way to be sure we have the right answer.&quot;","ref":"WiseGPTEx.OpenAIUtils.html#reasoning_prompt/1","title":"WiseGPTEx.OpenAIUtils.reasoning_prompt/1","type":"function"},{"doc":"A function that takes a message and completions with reasoning, and returns a string prompt for a researcher. The researcher is tasked with investigating the answer options provided, listing the flaws and faulty logic of each answer option. Example iex&gt; message = &quot;What is the capital of France?&quot; ...&gt; completions_with_reasoning = &quot;Option 1: Paris - This is the correct answer. Paris is the capital of France. \\n Option 2: London - This is incorrect. London is the capital of the United Kingdom, not France.&quot; ...&gt; WiseGPTEx.OpenAIUtils . researcher_prompt ( message , completions_with_reasoning ) &quot;What is the capital of France? \\n \\n Option 1: Paris - This is the correct answer. Paris is the capital of France. \\n Option 2: London - This is incorrect. London is the capital of the United Kingdom, not France. \\n \\n You are researcher tasked with investigating the answer options provided. List the flaws and faulty logic of each answer option. Let&#39;s work this out in a step by step way to be sure we have all the errors \\n \\n **Answer format:** \\n Correct Answer: &lt;Option Number&gt; \\n **If there are multiple correct answers, pick the first one.**&quot;","ref":"WiseGPTEx.OpenAIUtils.html#researcher_prompt/2","title":"WiseGPTEx.OpenAIUtils.researcher_prompt/2","type":"function"},{"doc":"A simple function that returns a static string. This string serves as an instruction for a &quot;resolver&quot; role, outlining the tasks it needs to perform. These tasks include: Identifying the best answer from a set of options. Improving the selected answer. Printing the improved answer in its entirety. Adding a special marker to the beginning of the improved answer. The string also includes a statement encouraging a step-by-step approach to ensure the correct answer is found. This function doesn't take any arguments and always returns the same string. Example iex&gt; WiseGPTEx.OpenAIUtils . resolver_prompt ( ) &quot;You are a resolver tasked with 1) finding which of the X answer options was best 2) improving that answer, 3) printing the improved answer in full, and 4) adding to the begining of the improved answer special marker &lt;|answerstart|&gt;. Let&#39;s work this out in step by step way to be sure we have the right answer:&quot;","ref":"WiseGPTEx.OpenAIUtils.html#resolver_prompt/0","title":"WiseGPTEx.OpenAIUtils.resolver_prompt/0","type":"function"},{"doc":"A function that extracts the resolver's answer from a string. The answer is expected to start within the special marker &lt;|answerstart|&gt; . If these markers are not found, the function returns the original string. Example iex&gt; answer = &quot;Some text before&lt;|answerstart|&gt;Hello&quot; ...&gt; WiseGPTEx.OpenAIUtils . trim_resolver_answer ( answer ) &quot;Hello&quot;","ref":"WiseGPTEx.OpenAIUtils.html#trim_resolver_answer/1","title":"WiseGPTEx.OpenAIUtils.trim_resolver_answer/1","type":"function"}]